<?php
/**
 * CleanPort theme functions
 */

if ( !isset( $content_width ) ) {
	$content_width = 990; /* pixels */
}

// themefurnace functions and definitions
function themefurnace_setup()
{
	load_theme_textdomain( 'cleanport', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );

// Post formats
	add_theme_support( 'post-formats', array( 'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );

// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'small-thumb', 45, 45, true );
	add_image_size( 'blog-thumb', 500, 400 );
	add_image_size( 'blog-full', 624, 365, true );
	add_image_size( 'portfolio-thumb', 480, 340, true );
	add_image_size( 'portfolio-full' );
	add_image_size( 'homepage-rotator' );

// Enable The custom Menu
	register_nav_menu( 'primary', __( 'Primary Menu', 'themefurnace' ) );

// Custom background
	$args = array(
		'default-color' => '#F9F9F9',
		'default-image' => '',
	);

	add_theme_support( 'custom-background',  apply_filters( 'themefurnace_custom_background_args', $args ) );
}
add_action( 'after_setup_theme', 'themefurnace_setup' );

// Style the Tag Cloud
function themefurnace_custom_tag_cloud_widget( $args )
{
	$args['largest'] = 12; //largest tag
	$args['smallest'] = 12; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['number'] = '8'; //number of tags
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'themefurnace_custom_tag_cloud_widget' );

/* This code filters the Categories archive widget to include the post count inside the link */
function themefurnace_cat_count_span( $links )
{
	$links = str_replace( '</a> (', ' (', $links );
	$links = str_replace( ')', ')</a>', $links );

	return $links;
}
add_filter( 'wp_list_categories', 'themefurnace_cat_count_span' );

/* This code filters the Archive widget to include the post count inside the link */
function themefurnace_archive_count_span( $links )
{
	$links = str_replace( '</a>&nbsp;(', ' (', $links );
	$links = str_replace( ')', ')</a>', $links );

	return $links;
}
add_filter( 'get_archives_link', 'themefurnace_archive_count_span' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis) and sets character length to 35
 */
function themefurnace_wp_new_excerpt( $text )
{
	if ( $text == '' ) {
		$text = get_the_content( '' );
		$text = strip_shortcodes( $text );
		$text = apply_filters( 'the_content', $text );
		$text = str_replace( ']]>', ']]>', $text );
		$text = strip_tags( $text );
		$text = nl2br( $text );
		$excerpt_length = apply_filters( 'excerpt_length', 25 );
		$words = explode( ' ', $text, $excerpt_length + 1 );
		if ( count( $words ) > $excerpt_length ) {
			array_pop( $words );
			array_push( $words, '' );
			$text = implode( ' ', $words );
		}
	}

	return $text;
}

remove_filter( 'get_the_excerpt', 'wp_trim_excerpt' );
add_filter( 'get_the_excerpt', 'themefurnace_wp_new_excerpt' );


/**
 * Register our sidebars and widgetized areas.
 *
 */
function themefurnace_widgets_init()
{

	register_sidebar( array(
		'name'          => 'Footer',
		'before_widget' => '<div class="footerwidget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="footertitle">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => 'Blog Sidebar',
		'before_widget' => '<div class="sidebarwidget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="sidetitle"><i class="fa fa-arrow-circle-o-right"></i>',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => 'Page Sidebar',
		'before_widget' => '<div class="sidebarwidget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="sidetitle"><i class="fa fa-arrow-circle-o-right"></i>',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => 'Main Features',
		'id'            => 'features-widget',
		'before_widget' => '<div class="feature">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="featuretitle">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => 'Small Features',
		'id'            => 'small-features-widget',
		'before_widget' => '<div class="featureitemsmall">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="hometitle">',
		'after_title'   => '</h3>',
	) );


}

add_action( 'widgets_init', 'themefurnace_widgets_init' );

// Pagination

function themefurnace_pagination( $pages = '', $range = 2 )
{
	global $paged;
	$showitems = ( $range * 2 ) + 1;

	if ( empty( $paged ) ) {
		$paged = 1;
	}
	if ( '' == $pages ) {
		global $wp_query;
		$pages = $wp_query->max_num_pages;
		if ( !$pages ) {
			$pages = 1;
		}
	}

	if ( 1 != $pages ) {
		echo '<div class="pagination">';
		if ( $paged > 2 && $paged > $range + 1 && $showitems < $pages ) {
			echo '<a href="' . get_pagenum_link( 1 ) . '">&laquo;</a>';
		}

		if ( $paged > 1 && $showitems < $pages ) {
			echo '<a href="' . get_pagenum_link( $paged - 1 ) . '">&lsaquo;</a>';
		}

		for ( $i = 1; $i <= $pages; $i++ ) {
			if ( 1 != $pages && ( !( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged == $i ) ? '<span class="current">' . $i . '</span>' : '<a href="' . get_pagenum_link( $i ) . '" class="inactive">' . $i . '</a>';
			}
		}

		if ( $paged < $pages && $showitems < $pages ) {
			echo '<a href="' . get_pagenum_link( $paged + 1 ) . '">&rsaquo;</a>';
		}
		if ( $paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages ) {
			echo '<a href="' . get_pagenum_link( $pages ) . '">&raquo;</a>';
		}
		echo "</div>\n";
	}
}


//Enqueue scripts and styles
function themefurnace_scripts()
{
	wp_enqueue_style( 'themefurnace-style', get_stylesheet_uri() );
	wp_enqueue_script( 'themefurnace-selectbox', get_template_directory_uri() . '/js/selectbox.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'themefurnace-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	wp_register_style( 'googleFonts', '//fonts.googleapis.com/css?family=Raleway:400,300,700', array(), false, 'all' );
	wp_enqueue_style( 'googleFonts' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'themefurnace-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}

	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/inc/flexslider/js/jquery.flexslider-min.js', array( 'jquery' ) );
	wp_enqueue_style( 'flexslider', get_template_directory_uri() . '/inc/flexslider/css/flexslider.css' );
}

add_action( 'wp_enqueue_scripts', 'themefurnace_scripts' );
require get_template_directory() . '/inc/flexslider/flexslider.php';

// default widgets
function themefurnace_add_theme_widgets( $old_theme, $WP_theme = null )
{

	if ( get_option( 'cleanport-lite-widgets-init', null ) !== null ) {
		return;
	}
	$activate = array(
		'sidebar-1' => array(
			'recent-posts-1',
			'meta-1',
			'categories-1',
			'archives-1'
		)
	);

	update_option( 'widget_recent-posts', array(
		1 => array( 'title' => __( 'Recent posts', 'cleanport' ) )
	) );

	update_option( 'widget_meta', array(
		1 => array( 'title' => __( 'Meta', 'cleanport' ) ),
	) );

	update_option( 'widget_categories', array(
		1 => array( 'title' => __( 'Categories', 'cleanport' ) ),
	) );

	update_option( 'widget_archives', array(
		1 => array( 'title' => __( 'Archives', 'cleanport' ) ),
	) );

	update_option( 'sidebars_widgets', $activate );
	update_option( 'cleanport-lite-widgets-init', 1 );

}

add_action( 'after_switch_theme', 'themefurnace_add_theme_widgets', 10, 2 );

// Load Extra Functions
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/extras.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/themesetup.php';
require get_template_directory() . '/inc/widgets.php';